# {{cookiecutter.integration_name}}

{{cookiecutter.integration_short_description}}

## Development Requirements

- Python3.11.0
- Pip
- Poetry (Python Package Manager)

## Installation

```sh
make install
```

## Runnning Localhost

`make run`


## Running Tests

`make test`

## Access Swagger Documentation

> <http://localhost:8080/docs>

## Access Redocs Documentation

> <http://localhost:8080/redoc>